google_maps_flutter_tizen library
Classes
- CircleController
-
The
CircleControllerclass wraps aGCircleand itsonTapbehavior. - CirclesController
-
This class manages all the CircleControllers associated to a
GoogleMapController. - ClusterManagersController
- A controller class for managing marker clustering.
- GeometryController
- The base class for all "geometry" group controllers.
- GoogleMapsController
- This class implements a Map Controller and its events
- GoogleMapsPlugin
-
The Tizen implementation of
GoogleMapsFlutterPlatform. - GroundOverlayController
-
The
GroundOverlayControllerclass wraps aGGroundOverlayand itsonTapbehavior. - GroundOverlaysController
-
This class manages a set of GroundOverlayControllers associated to a
GoogleMapController. - MapReadyEvent
-
A MapEvent event fired when a
mapIdon web is interactive. - MapTypeStyle
- MarkerController
-
The
MarkerControllerclass wraps aGMarker, how it handles events, and its associated (optional)GInfoWindowwidget. - MarkersController
-
This class manages a set of MarkerControllers associated to a
GoogleMapController. - PolygonController
-
The
PolygonControllerclass wraps aGPolygonand itsonTapbehavior. - PolygonsController
-
This class manages a set of PolygonControllers associated to a
GoogleMapController. - PolylineController
-
The
PolygonControllerclass wraps aGPolylineand itsonTapbehavior. - PolylinesController
-
This class manages a set of PolylinesControllers associated to a
GoogleMapController.
Constants
- kGoogleMapsControllerLongPressDuration → const int
- The duration of MapLongPressEvent.
Typedefs
- LatLngCallback = void Function(LatLng latLng)
-
A void function that handles a
LatLngas a parameter.