MarkerController class
The MarkerController class wraps a GMarker, how it handles events, and its associated (optional) GInfoWindow widget.
Constructors
- MarkerController({required GMarker marker, GInfoWindow? infoWindow, bool consumeTapEvents = false, LatLngCallback? onDragStart, LatLngCallback? onDrag, LatLngCallback? onDragEnd, VoidCallback? onTap, ClusterManagerId? clusterManagerId, WebViewController? controller})
-
Creates a
MarkerController, which wraps aGMarkerobject, itsonTap/onDragbehavior, and its associatedGInfoWindow.
Properties
- clusterManagerId → ClusterManagerId?
-
Returns
ClusterManagerIdif marker belongs to cluster.no setter - consumeTapEvents → bool
-
Returns
trueif this Controller will use its ownonTaphandler to consume events.no setter - dragEndEvent ↔ LatLngCallback?
-
Marker component's drag end event.
getter/setter pair
- dragEvent ↔ LatLngCallback?
-
Marker component's drag event.
getter/setter pair
- dragStartEvent ↔ LatLngCallback?
-
Marker component's drag start event.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- infoWindowShown → bool
-
Returns
trueif theGInfoWindowassociated to this marker is being shown.no setter - marker → GMarker?
-
Returns the
GMarkerassociated to this controller.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tapEvent ↔ VoidCallback?
-
Marker component's tap event.
getter/setter pair
Methods
-
hideInfoWindow(
) → void -
Hide the associated
GInfoWindow. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → void -
Disposes of the currently wrapped
GMarker. -
showInfoWindow(
) → void -
Show the associated
GInfoWindow. -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Marker marker, GMarkerOptions options, {String? newInfoWindowContent}) → void -
Updates the options of the wrapped
GMarkerobject.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited